@@ -2,7 +2,9 @@
 #RESPONSE =  request.RESPONSE
 
 request = container.REQUEST
-PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
+#PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
+
+PATH = context.getInstancePath()
 
 Otype = request['dol']
 
