@@ -4,8 +4,10 @@
 # This method is not used anywhere.
 import string
 
-path = '/'
-path = path + string.replace( context.surl, container.REQUEST['BASE0'], '')
+#path = '/'
+#path = path + string.replace( context.surl, container.REQUEST['BASE0'], '')
+
+path = context.getInstancePath()
 path = path + '/Data/' + type + '/' + name
 obj = context.restrictedTraverse(path)
 if obj.getProperty('Status') == 'Public':
