@@ -4,7 +4,8 @@
 # This module copies the facets from ObjectTypes
 import string
 FacetTypes = context.Data.FacetTypes.objectIds( )
-PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
+#PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
+PATH = context.getInstancePath()
 PATH = PATH + '/Data/'
 Type1 = ['float','int','long']
 Type2 = ['boolean']
