@@ -3,7 +3,8 @@
 import string
 inheritedObjectTypes=[]
 FacetTypes = context.Data.FacetTypes.objectIds( )
-PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
+#PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
+PATH = context.getInstancePath()
 PATH = PATH + '/Data/'
 Type1 = ['float','int','long']
 Type2 = ['boolean']
