@@ -3,7 +3,8 @@
 #request = container.REQUEST
 #RESPONSE =  request.RESPONSE
 
-PATH = string.replace(context.surl, container.REQUEST['BASE0'],'')
+#PATH = string.replace(context.surl, container.REQUEST['BASE0'],'')
+PATH = context.getInstancePath()
 
 otwocc = []
 
