@@ -1,6 +1,7 @@
 ##parameters=type,id
 
-PATH = string.replace(context.surl, container.REQUEST['BASE0'],'')  + '/Data/'+ type+ '/'+ id
+#PATH = string.replace(context.surl, container.REQUEST['BASE0'],'')  + '/Data/'+ type+ '/'+ id
+PATH = context.getInstancePath() + '/Data/' + type + '/' + id
 Ref = context.restrictedTraverse(PATH)
 
 cols=['column1','column2','column3','column4']
